/* This do file reproduces tables and figures in 
Bruhn, Miriam and Caio Piza. 2022. "Missing Information: Why Don’t More Firms Participate in Business Training?"

Last modified on: April 25, 2022 */

**Setting global directory
global path "C:\Users\wb532468\OneDrive - WBG\Desktop\Analysis"

**Set critical configurations
clear all
version 16
set matsize 1000
/*
**Installing required commands
ssc install ietoolkit, all replace
ssc install xml_tab, all replace
ssc install mat2txt, all replace
*/
do "${path}/Do files/ado/iebaltab.ado"

************************************************
* Classifying service types in SEBRAE data
************************************************

use "$path/Data/SEBRAE_Services.dta", clear

tab tipo_solução

gen service="networking" if tipo_solução=="Feira" | tipo_solução=="Missão/Caravana" | tipo_solução=="Rodada De Negócios" | tipo_solução=="Rodada de Negócios" | tipo_solução=="Rodada de Negócios a Distância"
replace service="consulting" if tipo_solução=="Consultoria" | tipo_solução=="Consultoria Presencial" | tipo_solução=="Consultoria a Distância"
replace service="class" if tipo_solução=="Cursos" | tipo_solução=="Cursos Presenciais" | tipo_solução=="Oficina" | tipo_solução=="Palestra" | tipo_solução=="Palestra a distância" | tipo_solução=="Seminário" | tipo_solução=="Seminário a distância"
replace service="material" if tipo_solução=="Orientação" | tipo_solução=="Orientação Presencial" | tipo_solução=="Orientação a Distância"

tab service if cod_produto==651 /*1st NaN visit*/
tab service if cod_produto==652 /*2nd NaN visit*/

**Service dummies excluding NaN visits
foreach var in networking consulting class material{
gen `var'=0
replace `var'=1 if service=="`var'" & cod_produto~=651 & cod_produto~=652
}

****************************************************************
* Coding months relative to treatment in SERBRAE services data
****************************************************************

**Reformatting start date
tostring data_atendimento_inicial, gen(temp)
gen start_date = date(temp, "YMD")
format %td start_date
drop temp

**Checking dates of NaN visits
sort id cod_produto start_date
by id cod_produto: gen N=_N
by id cod_produto: gen n=_n
tab N if cod_produto==651 /*Some firms had two 1st NaN visits*/
tab N if cod_produto==652 /*All firms have only one 2nd NaN visit*/

foreach code in 651 652{
bys id: gen temp=start_date if cod_produto==`code'
by id: egen date_`code'=max(temp)
drop temp
}
gen d=date_652-date_651
centile d if n==1 /*Median time between visits is 12 days*/

rename date_652 treat_date
list id if treat_date==.
replace treat_date=date_651+12 if treat_date==. /*Assume the 1 firm without 2nd NaN visit received the information 7 days after 1st NaN visit*/

**Month relative to treatment
gen norm_day=start_date-treat_date
gen norm_month=.
forvalues x=0/30{
*local y = `x' + 1
replace norm_month=`x' if norm_day>=30*`x' & norm_day<30*(`x'+1)
}
forvalues x=1/20{
replace norm_month=-`x' if norm_day>=-30*`x' & norm_day<-30*(`x'-1)
}
label var norm_month "Month relative to intervention"

**Calculating relative months that are there for all firms
tab start_date /*Earliest date is 08jan2017 (20827), last date is 23oct2020 (22211)*/
tab start_date if cod_produto==652 /*Earliest date is 26apr2018 (21300), last date is 21sep2018 (21448)*/
disp (21300-20827)/30 /*15 months --> use 1 year before treatment in analysis*/
disp (22211-21448)/30 /*25 months --> use 18 months after treatment in analysis to keep only pre-COVID data*/
drop if norm_month>18/*Dropping post-COVID data*/

**********************************************
* Converting SEBRAE services data to monthly
**********************************************

collapse (sum) networking consulting class material, by(id norm_month)

**Balanced panel
preserve
keep id
duplicates drop id, force
expand 31
sort id
egen norm_month=seq(), from(-12) to(18)
sort id norm_month
save balanced_panel, replace
restore

merge 1:1 id norm_month using balanced_panel
drop if _merge==1
erase balanced_panel.dta

**************************************************************************
* Coding monthly and cumulative services variables in SEBRAE data
**************************************************************************

gen service=networking+consulting+class+material
gen training=networking+consulting+class

foreach var in service training networking consulting class material{
replace `var'=0 if _merge==2
gen d_`var'=0
replace d_`var'=1 if `var'>0 & `var'~=.
}
drop _merge

sort id norm_month
by id: gen n=_n

**Cumulative consumption of SEBRAE services
foreach var in service training networking consulting class material{
gen `var'_c=`var'
replace `var'_c=. if norm_month<0
by id: replace `var'_c=`var'_c+`var'_c[_n-1] if norm_month>0
gen d_`var'_c=0
replace d_`var'_c=1 if `var'_c>0 & `var'_c~=.
}

**Cumulative baseline consumption of SEBRAE services
foreach var in service training networking consulting class material{
foreach x in 12{
gen aux=0
bys id: replace aux=1 if d_`var'==1 & norm_month>=-`x' & norm_month<0
bys id: egen d_`var'_c_minus`x'=max(aux)
drop aux
}
}

sum d_*_c d_*_c_minus12 if norm_month==12 /*Consulting and networking are less common --> group with class under training for the analyis to reduce number of hypotheses being tested*/
drop *networking* *consulting* *class*

label var service "Number of services received this month"
label var training "Number of classes/consulting/networking received this month"
label var material "Number of materials received this month"

label var d_service "Dummy: Any services received this month"
label var d_training "Dummy: Any classes/consulting/networking received this month"
label var d_material "Dummy: Any materials received this month"

label var service_c "Number of services received since treatment"
label var training_c "Number of classes/consulting/networking received since treatment"
label var material_c "Number of materials received since treatment"

label var d_service_c "Dummy: Any services received since treatment"
label var d_training_c "Dummy: Any classes/consulting/networking received since treatment"
label var d_material_c "Dummy: Any materials received since treatment"

label var d_service_c_minus12 "Dummy: Received any services within 12 months before treatment"
label var d_training_c_minus12 "Dummy: Received any classes/consulting/networking within 12 months before treatment"
label var d_material_c_minus12 "Dummy: Received any materials within 12 months before treatment"

*********************************************************
* Adding baseline and randomization variables
*********************************************************

merge m:1 id using "$path/Data/Baseline_NaN_RAIS.dta"
drop _merge 

**Firm age
format %tq bus_startdate
gen firm_age=2018-year(bus_startdate)
label var firm_age "Firm age in 2018 (years)"

**Generating treatment dummies
tab nome_relatorio /*Trat2 refers to motivation treatment; CA refers to automatic enrollment*/
gen treat_group=0 if nome_relatorio=="NaN Padrao"
replace treat_group=1 if nome_relatorio=="Trat1_CP"
replace treat_group=2 if nome_relatorio=="Trat1_CA"
replace treat_group=3 if nome_relatorio=="Trat2_CP"
replace treat_group=4 if nome_relatorio=="Trat2_CA"
label var treat_group "Experimental group"
label define treat_group 0 "Control" 1 "No motiv, no enroll" 2 "No motiv, enroll" 3 "Motiv, no enroll" 4 "Motiv, enroll", replace
label val treat_group treat_group

gen d_treat=0 if treat_group==0
replace d_treat=1 if treat_group>=1 & treat_group<=4
label var d_treat "Treatment dummy"

tab ind_primeiro_atend_sebrae if norm_month==-1 /*Only 12.6% had received SEBRAE services before, too few to look at heterogeneous effects*/

**Median business practices at baseline
egen bp_2018=rmean(p1 p2 p3 p4 p5 p6 p7 p8 p9 p10 p11 p12 p13 p14 p15 p16 p17 p18 p19 p20 p21 p22 p23 p24 p25 p26 p27 p28 p29)
gen bpbmed=1 if bp_2018<.5
replace bpbmed=0 if bp_2018>=.5 & bp_2018~=.
label var bp_2018 "2018 business practices score"
label var bpbmed "Dummy: 2018 BP below median"

**Generating treatment dummies by baseline busienss practices 
gen d_treat_bpbmed=d_treat
replace d_treat_bpbmed=0 if bpbmed==0
replace d_treat_bpbmed=. if bpbmed==.
label var d_treat_bpbmed "Treatment dummy for below median BP"

gen d_treat_bpamed=d_treat
replace d_treat_bpamed=0 if bpbmed==1
replace d_treat_bpamed=. if bpbmed==.
label var d_treat_bpamed "Treatment dummy for above median BP"

****************************************************
* Baseline balance tables
****************************************************

preserve
keep if norm_month==-1

**Table 1**
iebaltab d_service_c_minus12 d_material_c_minus12 d_training_c_minus12 bp_2018 n_employees_2015 avg_wage_2015 firm_age, grpvar(treat_group) rowvarlabels stdev save("$path/Results/table_1") replace 

**Table A1 (appendix)**
iebaltab d_service_c_minus12 d_material_c_minus12 d_training_c_minus12 bp_2018 n_employees_2015 avg_wage_2015 firm_age if bpbmed==1, grpvar(d_treat) rowvarlabels stdev save("$path/Results/table_A1a") replace 

iebaltab d_service_c_minus12 d_material_c_minus12 d_training_c_minus12 bp_2018 n_employees_2015 avg_wage_2015 firm_age if bpbmed==0, grpvar(d_treat) rowvarlabels stdev save("$path/Results/table_A1b") replace 

restore

****************************************************
* Figure and tables: SEBRAE Services
****************************************************

**Figure 3**
preserve

keep if norm_month>=0 & norm_month<=18

foreach var in service{
gen sd_`var'_c=d_`var'_c
}

collapse d_service_c (sd) sd_service_c , by(d_treat norm_month)

foreach var in service{
gen ub_`var'_c=d_`var'_c + 1.96*sd_`var'_c/sqrt(866)
gen lb_`var'_c=d_`var'_c - 1.96*sd_`var'_c/sqrt(866)
}

graph twoway rarea ub_service_c lb_service_c norm_month if d_treat==1, sort color(gs14)  ///
|| rarea ub_service_c lb_service_c norm_month if d_treat==0, sort color(gs14)  /// 
|| connected d_service_c norm_month if d_treat==1, msymbol(smcircle) mcolor(edkblue) lcolor(edkblue) ///
|| connected d_service_c norm_month if d_treat==0, msymbol(smcircle) mcolor(eltblue) lcolor(eltblue)  /// 
ytitle("Cumulative fraction with any SEBRAE service") ///
legend(order(3 4 2) label(3 "Any information sheet") label(4 "Control") label(2 "95% confidence intervals"))
graph save "$path/Results/figure_3.gph", replace

restore

xi: reg d_service_c d_treat d_service_c_minus12 i.strata if norm_month==18, r
estimates store test

xml_tab test, keep(d_treat) font("Times New Roman" 11) below stats(r2 N) tblanks(1) line(LAST_ROW 2 COL_NAMES 2) format(sclr0 nccr3 nccr3) sheet("test") save($path/Results/tables_2_3_4_5.xml) replace

estimates clear

**Table 2, Table 3, Table 4**
clear matrix 

matrix T = J(7, 4, . ) 
matrix rownames T = cmean pgroup2 pgroup3 pgroup4 pbpmed cbpbmed cbpamed
matrix colnames T = 3 6 12 18

foreach var in d_service_c d_material_c d_training_c{
foreach x in 3 6 12 18{

**Table 2, Table 3, Table 4: Panel A**
xi: reg `var' d_treat `var'_minus12 i.strata if norm_month==`x', r
estimates store `var'_all`x'
sum `var' if d_treat==0 & norm_month==`x'
mat T[rownumb(T, "cmean"), colnumb(T,"`x'")] = `r(mean)'

**Table 2, Table 3, Table 4: Panel B**
xi: reg `var' i.treat_group `var'_minus12 i.strata if norm_month==`x', r
estimates store `var'_gro`x'
test _Itreat_gro_1 = _Itreat_gro_2 
mat T[rownumb(T, "pgroup2"), colnumb(T,"`x'")] = `r(p)'
test _Itreat_gro_1 = _Itreat_gro_3
mat T[rownumb(T, "pgroup3"), colnumb(T,"`x'")] = `r(p)'
test _Itreat_gro_1 = _Itreat_gro_4
mat T[rownumb(T, "pgroup4"), colnumb(T,"`x'")] = `r(p)'

**Table 2, Table 3, Table 4: Panel C**
xi: reg `var' d_treat_bpbmed d_treat_bpamed bpbmed `var'_minus12 i.strata if norm_month==`x', r
estimates store `var'bpmed`x'
test d_treat_bpbmed = d_treat_bpamed 
mat T[rownumb(T, "pbpmed"), colnumb(T,"`x'")] = `r(p)'
sum `var' if d_treat==0 & norm_month==`x' & bpbmed==1
mat T[rownumb(T, "cbpbmed"), colnumb(T,"`x'")] = `r(mean)'
sum `var' if d_treat==0 & norm_month==`x' & bpbmed==0
mat T[rownumb(T, "cbpamed"), colnumb(T,"`x'")] = `r(mean)'

}

mat2txt, matrix(T) saving("$path/Results/Ftest_`var'.xls") replace

xml_tab *_all* *_gro* *bpmed*, keep(d_treat _Itreat_gro_1 _Itreat_gro_2 _Itreat_gro_3 _Itreat_gro_4 d_treat_bpbmed d_treat_bpamed bpbmed) font("Times New Roman" 11) below stats(r2 N) tblanks(1) line(LAST_ROW 2 COL_NAMES 2) format(sclr0 nccr3 nccr3) sheet("`var'") save($path/Results/tables_2_3_4_5.xml) append

estimates clear
}

****************************************************
* Adding data from follow-up survey and 2019 RAIS
****************************************************

keep if norm_month==18

merge 1:1 id using "$path/Data/Followup_Survey_RAIS.dta"
drop _merge 

**Coding 2019 business practices score
foreach var of varlist mkt_q1_a mkt_q1_b mkt_q1_d stk_q8 {
g 		dum_`var' = `var'
recode 	dum_`var' (99=.) (2=1)
}

foreach var of varlist rec_q17 {
g dum_`var' = cond(`var'==1,1,0) if `var'!=.
}

foreach var of varlist fin_q24 fin_q25_a {
g dum_`var' = cond(`var'==4,1,0) if `var'!=.
}
replace dum_fin_q25_a=0 if fin_q25==0
						
egen bp_2019 = rowmean (dum_mkt_q1_a dum_mkt_q1_b dum_mkt_q1_d mkt_q1_c mkt_q2 mkt_q3 ///
						stk_q7 dum_stk_q8 ///
						dum_rec_q17 rec_q19 rec_q20 rec_q21 ///
						dum_fin_q24 fin_q25 dum_fin_q25_a fin_q26) 
/*In line with NaN questionnaire, which counts each practice separately, include both fin_q25 and dum_fin_q25_a*/
label var bp_2019 "2019 business practices score"

**Coding other follow-up outcomes
tab fin_q28
foreach var in otherserv{
gen `var'=0 if fin_q28~=.
}
replace otherserv=1 if fin_q28==2

gen profit=sales-cost
replace profit=profit_declare if profit_confirm==0
gen ihsprofit=asinh(profit)

gen ihssales=asinh(sales)

**Attrition
tabstat delivery, by(d_treat)
xi: reg delivery d_treat i.strata, r
xi: reg delivery i.treat_group i.strata, r
test _Itreat_gro_1=_Itreat_gro_2
test _Itreat_gro_1=_Itreat_gro_3
test _Itreat_gro_1=_Itreat_gro_4

****************************************************
* Figure and tables: Follow-up Survey and RAIS
****************************************************

**Table 5**
*List of outcome variables
local yvars otherserv bp_2019 ihssales ihsprofit n_employees_2019 closed_2019

clear matrix 

local z: word count `yvars'
disp `z'

matrix T = J(7, 6, . ) 
matrix rownames T = cmean pgroup2 pgroup3 pgroup4 pbpmed cbpbmed cbpamed
matrix colnames T = `yvars'

gen b_otherserv=1
gen b_bp_2019=bp_2018
gen b_ihsprofit=1
gen b_ihssales=1
gen b_n_employees_2019=n_employees_2015
gen b_closed_2019=1

foreach x in `yvars'{

**Table 5: Panel A**
xi: reg `x' d_treat b_`x' i.strata, r
estimates store `x'_all
sum `x' if d_treat==0
mat T[rownumb(T, "cmean"), colnumb(T,"`x'")] = `r(mean)'

**Table 5: Panel B**
xi: reg `x' i.treat_group b_`x' i.strata, r
estimates store `x'_gro
test _Itreat_gro_1 = _Itreat_gro_2 
mat T[rownumb(T, "pgroup2"), colnumb(T,"`x'")] = `r(p)'
test _Itreat_gro_1 = _Itreat_gro_3
mat T[rownumb(T, "pgroup3"), colnumb(T,"`x'")] = `r(p)'
test _Itreat_gro_1 = _Itreat_gro_4
mat T[rownumb(T, "pgroup4"), colnumb(T,"`x'")] = `r(p)'

**Table 5: Panel C**
xi: reg `x' d_treat_bpbmed d_treat_bpamed bpbmed b_`x' i.strata, r
estimates store `x'bpmed
test d_treat_bpbmed = d_treat_bpamed 
mat T[rownumb(T, "pbpmed"), colnumb(T,"`x'")] = `r(p)'
sum `x' if d_treat==0 & bpbmed==1
mat T[rownumb(T, "cbpbmed"), colnumb(T,"`x'")] = `r(mean)'
sum `x' if d_treat==0 & bpbmed==0
mat T[rownumb(T, "cbpamed"), colnumb(T,"`x'")] = `r(mean)'

}

mat2txt, matrix(T) saving("$path/Results/Ftest_Followup_Survey_RAIS.xls") replace

xml_tab *_all* *_gro* *bpmed*, keep(d_treat _Itreat_gro_1 _Itreat_gro_2 _Itreat_gro_3 _Itreat_gro_4 d_treat_bpbmed d_treat_bpamed bpbmed) font("Times New Roman" 11) below stats(r2 N) tblanks(1) line(LAST_ROW 2 COL_NAMES 2) format(sclr0 nccr3 nccr3) sheet("Followup_Survey_RAIS") save($path/Results/tables_2_3_4_5.xml) append

estimates clear

**Reasons for not using services
**Table 6**
iebaltab noreturn_1-noreturn_6, grpvar(d_treat) rowvarlabels stdev onerow save("$path/Results/table_6") replace 

